import time

class Output(object):
    def __init__(self):
        self.context = ''
        self.level = 0
        self.timestamps = False

    def write(self, s, level, context=None):
        if context is None:
            context = self.context
        if level <= self.level:
            print '%s%s> %s' % (('', time.strftime('%H:%M:%S '))[self.level > 1 or self.timestamps], self.context, s)

    def writelines(self, lines, level):
        for line in lines:
            for line in line.rstrip('\n').split('\n'):
                self.write(line.rstrip('\n'), level)

out = Output()
